--[[
	Copyright (C) Udorn (Blackhand)
	
	This program is free software; you can redistribute it and/or
	modify it under the terms of the GNU General Public License
	as published by the Free Software Foundation; either version 2
	of the License, or (at your option) any later version.

	This program is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with this program; if not, write to the Free Software
	Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.	
--]]

--[[
	Snipe using bookmarks.
--]]
vendor.BookmarkSnipe = {}
vendor.BookmarkSnipe.prototype = {}
vendor.BookmarkSnipe.metatable = {__index = vendor.BookmarkSnipe.prototype}

--[[ 
	Creates a new instance.
--]]
function vendor.BookmarkSnipe:new(auctions)
	local instance = setmetatable({}, self.metatable)
	instance.auctions = auctions
	return instance
end

--[[
	Checks whether to snipe for a bookmarked item. Returns true and the reason, if the snipe should happen.
--]]
function vendor.BookmarkSnipe.prototype:Snipe(itemLink, itemName, count, bid, buyout)
	local data = self.db.factionrealm.wanted[itemName]
	local snipeBookmarked = self.db.profile.snipeBookmarked
	if (isFastScan) then
		snipeBookmarked = self.db.profile.fastSnipeBookmarked
	end
	if (snipeBookmarked and data) then
		local maxBidStr, maxBuyoutStr = strsplit(":", data)
		local maxBid = tonumber(maxBidStr)
		local maxBuyout = tonumber(maxBuyoutStr)
		maxBid = maxBid * count
		maxBuyout = maxBuyout * count
		if (buyout > 0 and maxBuyout > 0 and maxBuyout >= buyout) then
			local reason = L["Buyout is less or equal %s."]:format(vendor.Format.FormatMoney(maxBuyout))
			return true, reason
		elseif (maxBid > 0 and maxBid >= bid and not highBidder) then
			local reason = L["Bid is less or equal %s."]:format(vendor.Format.FormatMoney(maxBid))
			return true, reason
		end		
	end
	return false
end
