--[[
	Copyright (C) Udorn (Blackhand)
	
	This program is free software; you can redistribute it and/or
	modify it under the terms of the GNU General Public License
	as published by the Free Software Foundation; either version 2
	of the License, or (at your option) any later version.

	This program is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with this program; if not, write to the Free Software
	Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.	
--]]

vendor.ScanFrame = {}
vendor.ScanFrame.prototype = {}
vendor.ScanFrame.metatable = {__index = vendor.ScanFrame.prototype}

local AceGUI = LibStub("AceGUI-3.0")

local FRAME_HEIGHT = 600
local FRAME_WIDTH = 900
local TREE_WIDTH = 150
local SNIPERS_HEIGHT = 250
local TYPES_HEIGHT = 280
local TABLE_TOP = -51
local TABLE_WIDTH = FRAME_WIDTH - TREE_WIDTH - 20
local TABLE_HEIGHT = FRAME_HEIGHT - 55
local STOP_WIDTH = 60

local log = vendor.Debug:new("ScanFrame")
local L = vendor.Locale.GetInstance()

local function _HideAuctionFrame(self)
	self.auctionFrameScale = AuctionFrame:GetScale()
	AuctionFrame:SetScale(0.0001)
end

local function _RestoreAuctionFrame(self)
	AuctionFrame:SetScale(self.auctionFrameScale or 1)
end

local function _Stop(self)
	vendor.Scanner:StopScan()
end

local function _Hide(self)
	_Stop(self)
	self.frame:Hide()
	_RestoreAuctionFrame(self)
end

local function _OnUpdateFrame(self)
	if (vendor.Scanner:IsScanning()) then
		self.scanBut:Hide()
		self.stopBut:Show()
	else
		self.scanBut:Show()
		local _, allAllowed = vendor.Scanner:MaySendAuctionQuery()
		if (allAllowed) then
			self.scanBut:GetNormalTexture():SetVertexColor(0, 1, 0)
			self.scanBut:GetHighlightTexture():SetVertexColor(0, 1, 0)
			self.scanBut:GetPushedTexture():SetVertexColor(0, 1, 0)
			self.scanBut:SetBackdropColor(0, 1, 0)
		else
			self.scanBut:GetNormalTexture():SetVertexColor(1, 1, 1)
			self.scanBut:GetHighlightTexture():SetVertexColor(1, 1, 1)
			self.scanBut:GetPushedTexture():SetVertexColor(1, 1, 1)
			self.scanBut:SetBackdropColor(1, 1, 1)
		end
		self.stopBut:Hide()
	end
end

local function _InitFrame(self)
   -- create the frame
	local frame = CreateFrame("Frame", nil, UIParent, "VendorDialogTemplate")
	frame.obj = self
	self.frame = frame
	frame:SetWidth(FRAME_WIDTH)
	frame:SetHeight(FRAME_HEIGHT)
	frame:SetPoint("CENTER")
	frame:SetFrameStrata("DIALOG")
	frame:SetMovable(true)
	frame:EnableMouse(true)
	frame:SetToplevel(true)
--	frame:SetClampedToScreen(true)
	frame:SetScript("OnMouseDown", function() this:StartMoving() end)
	frame:SetScript("OnMouseUp", function() this:StopMovingOrSizing() end)
				
	-- title string
	local text = frame:CreateFontString(nil, "OVERLAY")
	text:SetPoint("TOP", frame, "TOP", 0, -10)
	text:SetFontObject("GameFontHighlightLarge")
	text:SetText(L["Scanner"])
	
	-- close button
	local but = CreateFrame("Button", nil, frame, "UIPanelCloseButton")
	but.obj = self
	but:SetPoint("TOPRIGHT", 3, 0)
	but:SetScript("OnClick", function(but) _Hide(but.obj) end)
	
	-- status bar 
	local statusBar = CreateFrame("StatusBar", name, frame, "TextStatusBar")
	self.statusBar = statusBar
	statusBar:SetHeight(14)
	statusBar:SetWidth(FRAME_WIDTH - STOP_WIDTH - 15)
	statusBar:SetStatusBarTexture("Interface\\TargetingFrame\\UI-StatusBar")
	statusBar:SetPoint("TOPLEFT", 5, -30)
	statusBar:SetMinMaxValues(0, 1)
	statusBar:SetValue(0)
	statusBar:SetStatusBarColor(0, 1, 0)
	
	-- status bar text
	local text = statusBar:CreateFontString(nil, "ARTWORK")
	self.statusBarText = text
	text:SetPoint("CENTER", statusBar)
	text:SetFontObject("GameFontHighlight")
	text:SetText("1000/166363 auctions")
	
	-- stop button 
	local but = CreateFrame("Button", nil, frame, "UIPanelButtonTemplate")
	but.obj = self
	but:SetText(L["Stop"])
	but:SetWidth(STOP_WIDTH)
	but:SetHeight(20)
	but:SetPoint("TOPRIGHT", -5, -27)
	but:SetScript("OnClick", function(but) _Stop(but.obj) end)
	self.stopBut = but
	
	-- scan button 
	local but = CreateFrame("Button", nil, frame, "UIPanelButtonTemplate")
	but.obj = self
	but:SetText(L["Scan"])
	but:SetWidth(STOP_WIDTH)
	but:SetHeight(20)
	but:SetPoint("TOPRIGHT", -5, -27)
	but:SetScript("OnClick", function(but) vendor.Scanner:Scan() end)
	self.scanBut = but
	
	-- scan/stop switch
	frame:SetScript("OnUpdate", function(frame) _OnUpdateFrame(frame.obj) end)
	
	-- selected snipers
	local tree = {}
	for i=1,20 do
		table.insert(tree, {value = i, text = "MANNNNN"..i})
	end
	local snipes = AceGUI:Create("TreeMenu")
	snipes:SetTree(tree)
	snipes:SetWidth(TREE_WIDTH)
	snipes:SetHeight(SNIPERS_HEIGHT)
	snipes.frame:SetParent(frame)
	snipes:SetPoint("TOPLEFT", 5, TABLE_TOP)
	snipes:SetTitle("Snipes")
	
	-- selected types
	local types = AceGUI:Create("TreeMenu")
	types:SetTree(tree)
	types:SetWidth(TREE_WIDTH)
	types:SetHeight(TYPES_HEIGHT)
	types.frame:SetParent(frame)
	types:SetPoint("TOPLEFT", snipes.frame, "BOTTOMLEFT", 0, -15)
	types:SetTitle("Types")
	
	frame:Show()
end

local function _Init(self)
	_InitFrame(self)
	local itemModel = vendor.ScannerItemModel:new()
	self.itemModel = itemModel
	local cmds-- = vendor.Vendor:OrderTable(CMDS)
	local cfg = {
		name = "AMScannerAuctions",
		parent = self.frame,
		itemModel = itemModel,
		cmds = cmds,
		config = vendor.Scanner.db.profile.scannerItemTableCfg,
		width = TABLE_WIDTH,
		height = TABLE_HEIGHT,
		xOff = TREE_WIDTH + 10,
		yOff = TABLE_TOP,
		sortButtonBackground = true,
	}
	local itemTable = vendor.ItemTable:new(cfg)
	self.itemTable = itemTable
	--self.frame:Hide()
	self:ClearProgress()
end

--[[ 
	Creates a new instance.
--]]
function vendor.ScanFrame:new()
	local instance = setmetatable({}, self.metatable)
	_Init(instance)
	return instance
end

--[[
	Sets the progress together with the given message.
--]]
function vendor.ScanFrame.prototype:SetProgress(msg, percent)
--	self:Show()
	self.statusBar:SetValue(percent)
	self.statusBarText:SetText(msg)
end

--[[
	Clears the progres bar.
--]]
function vendor.ScanFrame.prototype:ClearProgress()
	self.statusBar:SetValue(0)
	self.statusBarText:SetText("")
end

--[[
	Closes the scanner frame.
--]]
function vendor.ScanFrame.prototype:Hide()
	_Hide(self)
end

--[[
	Ensures that the scan frame is visible.
--]]
function vendor.ScanFrame.prototype:Show()
	if (not self.frame:IsVisible()) then
		_HideAuctionFrame(self)
		self.frame:Show()
	end
end